
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('hunspell -l -d en_US');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
CFG
CMD
COMMITID
CPQD
CentOS
Chaves
CheckCommit
CheckDiff
CheckFile
CheckJira
CheckLog
CheckReference
CheckRewrite
CheckWhitespace
Dave
Dockerfile
FIGlet
FILTERs
GerritChangeId
Git
GitHooks
Gitiles
Gustavo
Hooks
JGit
Joyjit
Kawaguchi
Kohsuke
Koivunalho
MediaWiki
Message
Mikko
NEWCOMMIT
Nath
Nieznański
Notify
OLDCOMMIT
OpenStack
PATHSPEC
PATHSPECS
PATTERNs
Plugin
PrepareLog
REFSPECs
RHEL
RULEs
RemoteIssue
Repository
Rolsky
SHA1
SPECs
StackOverflow
Szymon
TODO
Test
Torvalds
Tutorial
USERSPEC
Wikimedia
acked
acl
acls
applypatch
aren
atlassian
autarch
bitbucket
canonicalization
checkcommit
checkfile
checkjira
checklog
checkreference
checkwhitespace
codespec
commentSizeLimit
cowsay
de
doesn
find
fixversion
fqdn
gerrit
githooks
gitlab
gnustavo
groupname
groupspec
html
isn
jira
jirapass
jiraurl
jirauser
jql
lang
lib
macOS
mailmap
matchkey
matchlog
mikkoi
msg
mxcheck
natively
nez
nocheck
noref
patchset
patchsets
pathspec
pathspecs
prev
rebase
rebased
rebases
rebasing
refspec
refspecs
reimplementation
scalable
scripts
section2
shouldn
sizelimit
src
tldcheck
userenv
v2
v3
ve
www
